.. _cloud_guides:

**************************
Legacy Public Cloud Guides
**************************

The legacy guides in this section may be out of date. They cover using Ansible with a range of public cloud platforms. They explore particular use cases in greater depth and provide a more "top-down" explanation of some basic features.

Guides for using public clouds are moving into collections. We are migrating these guides into collections. Please update your links for the following guides:

:ref:`ansible_collections.amazon.aws.docsite.aws_intro`

.. toctree::
   :maxdepth: 1

   guide_alicloud
   guide_cloudstack
   guide_gce
   guide_azure
   guide_online
   guide_oracle
   guide_packet
   guide_rax
   guide_scaleway
   guide_vultr
